for x in /dev/md/* ; do
	mdadm --stop $x
done

for disk in $(list-devices disk); do
	wipefs -a /dev/$disk[p][0-9]
	wipefs -a /dev/$disk
	mdadm --zero-superblock /dev/$disk
	dd if=/dev/zero of=/dev/$disk bs=512 count=32
	blkdiscard --secure /dev/${disk}
	parted -s /dev/${disk} mklabel gpt;
	partprobe
done

for x in /dev/md[0-9]* ; do
	mdadm --stop $x
done

if grep -q QEMU /proc/cpuinfo || dmesg | grep -q 'Manufacturer: QEMU' ; then
	export WITHOUT_SWAP=yes
fi
sleep 2
list-devices disk | head -4 | tr '\n' ' ' > /tmp/list-devices
read DISKA DISKB DISKC DISKD < /tmp/list-devices
SIZE1=$(fdisk -l "${DISKA}" 2>/dev/null|grep Disk|grep dev|cut -d' ' -f5)
MBR_LIMIT=2000000000000

getpart() {
	local partnum disk
	disk=${1}
	partnum=${2}
	if echo "${disk}" | grep -q nvme; then
		echo "${disk}p${partnum}"
	else
		echo "${disk}${partnum}"
	fi
}

get_raid_parts() {
	local partnum disks resstr del
	partnum=${1}
	shift
	disks=${@}
	for disk in ${disks}; do
		if [ -n "${resstr}" ]; then
			del="#"
		else
			del=""
		fi
		resstr="${resstr}${del}$(getpart ${disk} ${partnum})"
	done
	echo ${resstr}
}

debconf-set partman-basicfilesystems/choose_label gpt
debconf-set partman-basicfilesystems/default_label gpt
debconf-set partman-partitioning/choose_label gpt
debconf-set partman-partitioning/default_label gpt
debconf-set partman/choose_label gpt
debconf-set partman/default_label gpt
if [ -d /sys/firmware/efi ]; then
	debconf-set partman-efi/non_efi_system true
fi
debconf-set mdadm/boot_degraded true
debconf-set partman-auto/disk "${DISKA} ${DISKB} ${DISKC} ${DISKD}"
debconf-set partman-auto/method "raid"
debconf-set partman-md/device_remove_md true
BOOT_DSIZE=$(parted -sm ${DISKA} unit GB print | grep -e "${DISKA}" | cut -d: -f2 | sed -e 's/GB$//' | cut -d. -f1) 
if [ -z "${BOOT_DSIZE}" ]; then BOOT_DSIZE=0 ; fi
BOOT_LIMIT=3000
if [ ${BOOT_DSIZE} -ge ${BOOT_LIMIT} ]; then
	WITH_BOOT=yes
fi
bootsize=256
if [ -d /sys/firmware/efi ]; then
	debconf-set partman-auto/expert_recipe "multiraid :: \
		300 200 500 free \$iflabel{ gpt } \$reusemethod{ } method{ efi } format{ } . \
		$(test -n "${WITH_BOOT}" && echo "${bootsize} 50 ${bootsize}} raid \$primary{ } method{ raid } .") \
		128 512 100% raid \$gptonly{ } \$primary method{ raid }	. \
		1024 10000 1000000000 raid \$gptonly{ } \$primary method{ raid }	. "
  echo "$(getpart ${DISKA} 1)" >> /tmp/first_efi_part
  echo "$(getpart ${DISKB} 1)" >> /tmp/second_efi_parts
  echo "$(getpart ${DISKC} 1)" >> /tmp/second_efi_parts
  echo "$(getpart ${DISKD} 1)" >> /tmp/second_efi_parts
else
	debconf-set partman-auto/expert_recipe "multiraid :: \
		1 1 1 free	\$gptonly{ } \$primary{ } \$bios_boot{ } method{ biosgrub } . \
		$(test -n "${WITH_BOOT}" && echo "${bootsize} 50 ${bootsize}} raid \$primary{ } method{ raid } .") \
		128 512 100% raid \$gptonly{ } \$primary method{ raid }	. \
		1024 10000 1000000000 raid \$gptonly{ } \$primary method{ raid }	. "
fi
if [ -n "${WITH_BOOT}" ]; then
debconf-set partman-auto-raid/recipe " \
	1 4 0 ext2 /boot $(get_raid_parts 2 ${DISKA} ${DISKB} ${DISKC} ${DISKD}) . \
	10 4 0 swap - $(get_raid_parts 3 ${DISKA} ${DISKB} ${DISKC} ${DISKD}) . \
	10 4 0 ext4 / $(get_raid_parts 4 ${DISKA} ${DISKB} ${DISKC} ${DISKD}) . "
else
debconf-set partman-auto-raid/recipe " \
	10 4 0 swap - $(get_raid_parts 2 ${DISKA} ${DISKB} ${DISKC} ${DISKD}) . \
	10 4 0 ext4 / $(get_raid_parts 3 ${DISKA} ${DISKB} ${DISKC} ${DISKD}) . "
fi
debconf-set grub-installer/bootdev "${DISKA} ${DISKB} ${DISKC} ${DISKD}"
